# Generated by Django 3.2.23 on 2023-11-28 14:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0066_collection_management_permissions'),
        ('coyote', '0010_auto_20231127_1018'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='ColorSetting',
            new_name='StyleSettings',
        ),
    ]



# Generated by Django 3.2.20 on 2023-09-07 10:00

from django.db import migrations, models
import django.db.models.deletion
import wagtail.blocks
import wagtail.fields
import wagtail.images.blocks


class Migration(migrations.Migration):
    dependencies = [
        ("wagtailcore", "0066_collection_management_permissions"),
        ("coyote", "0002_auto_20230831_1631"),
    ]

    operations = [
        migrations.CreateModel(
            name="CoyoteContactPage",
            fields=[
                (
                    "page_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        serialize=False,
                        to="wagtailcore.page",
                    ),
                ),
                (
                    "header",
                    wagtail.fields.StreamField(
                        [
                            (
                                "Foto",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ]
                                ),
                            ),
                            (
                                "Video",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "video",
                                            wagtail.blocks.CharBlock(
                                                label="Video", required=False
                                            ),
                                        ),
                                        (
                                            "position",
                                            wagtail.blocks.ChoiceBlock(
                                                choices=[
                                                    ("full-screen", "Achtergrond"),
                                                    ("media-side", "Next to content"),
                                                ],
                                                label="Postion of the media",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                    ]
                                ),
                            ),
                            (
                                "Content",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "position",
                                            wagtail.blocks.ChoiceBlock(
                                                choices=[
                                                    ("left", "Links"),
                                                    ("right", "Rechts"),
                                                ],
                                                label="Postion of the image",
                                                required=False,
                                            ),
                                        ),
                                    ]
                                ),
                            ),
                        ],
                        blank=True,
                        verbose_name="Header",
                    ),
                ),
                (
                    "content",
                    wagtail.fields.StreamField(
                        [
                            (
                                "Afbeelding_met_tekst",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ],
                                    icon="image",
                                ),
                            ),
                            (
                                "Iconen_met_tekst",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "layout",
                                            wagtail.blocks.ChoiceBlock(
                                                choices=[
                                                    (
                                                        "layout1",
                                                        "coyote/layouts/icon_layout_1.svg",
                                                    ),
                                                    (
                                                        "layout2",
                                                        "coyote/layouts/icon_layout_2.svg",
                                                    ),
                                                ]
                                            ),
                                        ),
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "icons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "icon",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "header",
                                                            wagtail.blocks.CharBlock(
                                                                label="Header",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "body",
                                                            wagtail.blocks.TextBlock(
                                                                label="Short text",
                                                                max_length=100,
                                                                required=True,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Text Block",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "button",
                                            wagtail.blocks.StructBlock(
                                                [
                                                    (
                                                        "label",
                                                        wagtail.blocks.CharBlock(
                                                            required=False
                                                        ),
                                                    ),
                                                    (
                                                        "page_url",
                                                        wagtail.blocks.PageChooserBlock(
                                                            required=False
                                                        ),
                                                    ),
                                                    (
                                                        "external_url",
                                                        wagtail.blocks.CharBlock(
                                                            help_text="You can also use the mailto: or tel: preset for functional use",
                                                            label="External url",
                                                            required=False,
                                                        ),
                                                    ),
                                                    (
                                                        "new_tab",
                                                        wagtail.blocks.BooleanBlock(
                                                            default=False,
                                                            label="Open in new tab",
                                                            required=False,
                                                        ),
                                                    ),
                                                    (
                                                        "button_style",
                                                        wagtail.blocks.ChoiceBlock(
                                                            choices=[
                                                                ("primary", "Primary"),
                                                                (
                                                                    "secondary",
                                                                    "Secondary",
                                                                ),
                                                                ("light", "Light"),
                                                                ("dark", "Dark"),
                                                                ("info", "Info"),
                                                                ("success", "Success"),
                                                                ("warning", "Warning"),
                                                                ("danger", "Danger"),
                                                            ],
                                                            label="Button style",
                                                            required=False,
                                                        ),
                                                    ),
                                                ],
                                                required=False,
                                            ),
                                        ),
                                    ],
                                    icon="info-circle",
                                ),
                            ),
                            (
                                "Center_tekts",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ],
                                    icon="collapse-down",
                                ),
                            ),
                            (
                                "Logos",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "logos",
                                            wagtail.blocks.ListBlock(
                                                wagtail.images.blocks.ImageChooserBlock(),
                                                required=False,
                                            ),
                                        )
                                    ],
                                    icon="tag",
                                ),
                            ),
                            (
                                "Quotes",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ],
                                    icon="openquote",
                                ),
                            ),
                            (
                                "Jumbotron",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ],
                                    icon="form",
                                ),
                            ),
                            (
                                "Accordeon",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ],
                                    icon="list-ul",
                                ),
                            ),
                            (
                                "Producten",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ],
                                    icon="tag",
                                ),
                            ),
                            (
                                "Categorieen",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ],
                                    icon="clipboard-list",
                                ),
                            ),
                        ],
                        blank=True,
                        verbose_name="Inhoud",
                    ),
                ),
                (
                    "footer",
                    wagtail.fields.StreamField(
                        [
                            (
                                "Call_To_Action",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ],
                                    icon="chain-broken",
                                ),
                            ),
                            (
                                "Nieuwsbrief",
                                wagtail.blocks.StructBlock(
                                    [
                                        (
                                            "body",
                                            wagtail.blocks.RichTextBlock(
                                                label="Inhoud", required=True
                                            ),
                                        ),
                                        (
                                            "buttons",
                                            wagtail.blocks.ListBlock(
                                                wagtail.blocks.StructBlock(
                                                    [
                                                        (
                                                            "label",
                                                            wagtail.blocks.CharBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "page_url",
                                                            wagtail.blocks.PageChooserBlock(
                                                                required=False
                                                            ),
                                                        ),
                                                        (
                                                            "external_url",
                                                            wagtail.blocks.CharBlock(
                                                                help_text="You can also use the mailto: or tel: preset for functional use",
                                                                label="External url",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "new_tab",
                                                            wagtail.blocks.BooleanBlock(
                                                                default=False,
                                                                label="Open in new tab",
                                                                required=False,
                                                            ),
                                                        ),
                                                        (
                                                            "button_style",
                                                            wagtail.blocks.ChoiceBlock(
                                                                choices=[
                                                                    (
                                                                        "primary",
                                                                        "Primary",
                                                                    ),
                                                                    (
                                                                        "secondary",
                                                                        "Secondary",
                                                                    ),
                                                                    ("light", "Light"),
                                                                    ("dark", "Dark"),
                                                                    ("info", "Info"),
                                                                    (
                                                                        "success",
                                                                        "Success",
                                                                    ),
                                                                    (
                                                                        "warning",
                                                                        "Warning",
                                                                    ),
                                                                    (
                                                                        "danger",
                                                                        "Danger",
                                                                    ),
                                                                ],
                                                                label="Button style",
                                                                required=False,
                                                            ),
                                                        ),
                                                    ]
                                                ),
                                                label="Buttons",
                                                required=False,
                                            ),
                                        ),
                                        (
                                            "image",
                                            wagtail.images.blocks.ImageChooserBlock(
                                                label="Afbeelding"
                                            ),
                                        ),
                                        (
                                            "overlay",
                                            wagtail.blocks.BooleanBlock(
                                                label="Dark overlay", required=False
                                            ),
                                        ),
                                        (
                                            "center_text",
                                            wagtail.blocks.BooleanBlock(
                                                label="Center the body", required=False
                                            ),
                                        ),
                                    ],
                                    icon="mail",
                                ),
                            ),
                        ],
                        blank=True,
                        verbose_name="Footer",
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
            bases=("wagtailcore.page",),
        ),
        migrations.AlterField(
            model_name="coyotehomepage",
            name="content",
            field=wagtail.fields.StreamField(
                [
                    (
                        "Afbeelding_met_tekst",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="image",
                        ),
                    ),
                    (
                        "Iconen_met_tekst",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "layout",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            (
                                                "layout1",
                                                "coyote/layouts/icon_layout_1.svg",
                                            ),
                                            (
                                                "layout2",
                                                "coyote/layouts/icon_layout_2.svg",
                                            ),
                                        ]
                                    ),
                                ),
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "icons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "icon",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "header",
                                                    wagtail.blocks.CharBlock(
                                                        label="Header", required=False
                                                    ),
                                                ),
                                                (
                                                    "body",
                                                    wagtail.blocks.TextBlock(
                                                        label="Short text",
                                                        max_length=100,
                                                        required=True,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Text Block",
                                        required=False,
                                    ),
                                ),
                                (
                                    "button",
                                    wagtail.blocks.StructBlock(
                                        [
                                            (
                                                "label",
                                                wagtail.blocks.CharBlock(
                                                    required=False
                                                ),
                                            ),
                                            (
                                                "page_url",
                                                wagtail.blocks.PageChooserBlock(
                                                    required=False
                                                ),
                                            ),
                                            (
                                                "external_url",
                                                wagtail.blocks.CharBlock(
                                                    help_text="You can also use the mailto: or tel: preset for functional use",
                                                    label="External url",
                                                    required=False,
                                                ),
                                            ),
                                            (
                                                "new_tab",
                                                wagtail.blocks.BooleanBlock(
                                                    default=False,
                                                    label="Open in new tab",
                                                    required=False,
                                                ),
                                            ),
                                            (
                                                "button_style",
                                                wagtail.blocks.ChoiceBlock(
                                                    choices=[
                                                        ("primary", "Primary"),
                                                        ("secondary", "Secondary"),
                                                        ("light", "Light"),
                                                        ("dark", "Dark"),
                                                        ("info", "Info"),
                                                        ("success", "Success"),
                                                        ("warning", "Warning"),
                                                        ("danger", "Danger"),
                                                    ],
                                                    label="Button style",
                                                    required=False,
                                                ),
                                            ),
                                        ],
                                        required=False,
                                    ),
                                ),
                            ],
                            icon="info-circle",
                        ),
                    ),
                    (
                        "Center_tekts",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="collapse-down",
                        ),
                    ),
                    (
                        "Logos",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "logos",
                                    wagtail.blocks.ListBlock(
                                        wagtail.images.blocks.ImageChooserBlock(),
                                        required=False,
                                    ),
                                )
                            ],
                            icon="tag",
                        ),
                    ),
                    (
                        "Quotes",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="openquote",
                        ),
                    ),
                    (
                        "Jumbotron",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="form",
                        ),
                    ),
                    (
                        "Accordeon",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="list-ul",
                        ),
                    ),
                    (
                        "Producten",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="tag",
                        ),
                    ),
                    (
                        "Categorieen",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="clipboard-list",
                        ),
                    ),
                ],
                blank=True,
                verbose_name="Inhoud",
            ),
        ),
        migrations.AlterField(
            model_name="coyotehomepage",
            name="footer",
            field=wagtail.fields.StreamField(
                [
                    (
                        "Call_To_Action",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="chain-broken",
                        ),
                    ),
                    (
                        "Nieuwsbrief",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ],
                            icon="mail",
                        ),
                    ),
                ],
                blank=True,
                verbose_name="Footer",
            ),
        ),
        migrations.AlterField(
            model_name="coyotehomepage",
            name="header",
            field=wagtail.fields.StreamField(
                [
                    (
                        "Foto",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                                (
                                    "center_text",
                                    wagtail.blocks.BooleanBlock(
                                        label="Center the body", required=False
                                    ),
                                ),
                            ]
                        ),
                    ),
                    (
                        "Video",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "video",
                                    wagtail.blocks.CharBlock(
                                        label="Video", required=False
                                    ),
                                ),
                                (
                                    "position",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            ("full-screen", "Achtergrond"),
                                            ("media-side", "Next to content"),
                                        ],
                                        label="Postion of the media",
                                        required=False,
                                    ),
                                ),
                                (
                                    "overlay",
                                    wagtail.blocks.BooleanBlock(
                                        label="Dark overlay", required=False
                                    ),
                                ),
                            ]
                        ),
                    ),
                    (
                        "Content",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "body",
                                    wagtail.blocks.RichTextBlock(
                                        label="Inhoud", required=True
                                    ),
                                ),
                                (
                                    "buttons",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "label",
                                                    wagtail.blocks.CharBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "page_url",
                                                    wagtail.blocks.PageChooserBlock(
                                                        required=False
                                                    ),
                                                ),
                                                (
                                                    "external_url",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="You can also use the mailto: or tel: preset for functional use",
                                                        label="External url",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "new_tab",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=False,
                                                        label="Open in new tab",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "button_style",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("primary", "Primary"),
                                                            ("secondary", "Secondary"),
                                                            ("light", "Light"),
                                                            ("dark", "Dark"),
                                                            ("info", "Info"),
                                                            ("success", "Success"),
                                                            ("warning", "Warning"),
                                                            ("danger", "Danger"),
                                                        ],
                                                        label="Button style",
                                                        required=False,
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Buttons",
                                        required=False,
                                    ),
                                ),
                                (
                                    "image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Afbeelding"
                                    ),
                                ),
                                (
                                    "position",
                                    wagtail.blocks.ChoiceBlock(
                                        choices=[
                                            ("left", "Links"),
                                            ("right", "Rechts"),
                                        ],
                                        label="Postion of the image",
                                        required=False,
                                    ),
                                ),
                            ]
                        ),
                    ),
                ],
                blank=True,
                verbose_name="Header",
            ),
        ),
    ]



# Generated by Django 3.2.23 on 2023-11-17 08:45

from django.db import migrations, models
import wagtail.blocks
import wagtail.fields
import wagtail.embeds.blocks
import wagtail.images.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('coyote', '0008_rename_body_bg_colorsetting_body_background'),
    ]

    operations = [
        migrations.AlterField(
            model_name='colorsetting',
            name='gray_200',
            field=models.CharField(default='#e9ecef', max_length=7, verbose_name='Light'),
        ),
        migrations.AlterField(
            model_name='colorsetting',
            name='gray_900',
            field=models.CharField(default='#0B2936', max_length=7, verbose_name='Dark'),
        ),
        migrations.AlterField(
            model_name='colorsetting',
            name='primary',
            field=models.CharField(default='#7772F6', max_length=7),
        ),
        migrations.AlterField(
            model_name='colorsetting',
            name='secondary',
            field=models.CharField(default='#6c757d', max_length=7),
        ),
        migrations.AlterField(
            model_name='coyotehomepage',
            name='header',
            field=wagtail.fields.StreamField([('Foto', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))])), ('Video', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('layout', wagtail.blocks.ChoiceBlock(choices=[('layout1', 'coyote/layouts/video_layout_1.png'), ('layout2', 'coyote/layouts/video_layout_2.png')])), ('video', wagtail.embeds.blocks.EmbedBlock(label='Video', required=False)), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False))])), ('Content', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('position', wagtail.blocks.ChoiceBlock(choices=[('left', 'Links'), ('right', 'Rechts')], label='Postion of the image', required=False))]))], blank=True, verbose_name='Header'),
        ),
    ]



# Generated by Django 5.2.3 on 2025-09-29 14:03

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0021_fix_incorrect_header_default_setting"),
        ("ocyan_plugin_wagtail", "0029_alter_abstractbasepage_canonical_url"),
    ]

    operations = [
        migrations.AddField(
           model_name="coyotehomepage",
           name="abstractbasepage_ptr",
           field=models.IntegerField(null=True, blank=True),
           preserve_default=False,
       ),
       migrations.AddField(
           model_name="coyotecontactpage",
           name="abstractbasepage_ptr",
           field=models.IntegerField(null=True, blank=True),
           preserve_default=False,
       )
    ]



ICONS = [
    ("share-nodes-solid", "share-nodes-solid"),
    ("share-nodes", "share-nodes"),
    ("share", "share"),
    ("share-from-square", "share-from-square"),
    ("spider-web", "spider-web"),
    ("folder", "folder"),
    ("folder-solid", "folder-solid"),
    ("list-check", "list-check"),
    ("cloud-arrow-down", "cloud-arrow-down"),
    ("cloud-arrow-down-solid", "cloud-arrow-down-solid"),
    ("download-solid", "download-solid"),
    ("upload", "upload"),
    ("upload-solid", "upload-solid"),
    ("cloud-arrow-up-solid", "cloud-arrow-up-solid"),
    ("cloud-arrow-up", "cloud-arrow-up"),
    ("home", "home"),
    ("phone", "phone"),
    ("comment", "comment"),
    ("cart-arrow-down", "cart-arrow-down"),
    ("cart-shopping-fast", "cart-shopping-fast"),
    ("shopping-cart", "shopping-cart"),
    ("shopping-cart-solid", "shopping-cart-solid"),
    ("trash", "trash"),
    ("arrow-down-arrow-up", "arrow-down-arrow-up"),
    ("sort-numeric-down-alt", "sort-numeric-down-alt"),
    ("sort-alpha-down", "sort-alpha-down"),
    ("circle", "circle"),
    ("filter", "filter"),
    ("cloud", "cloud"),
    ("letter", "letter"),
    ("letter-open", "letter-open"),
    ("envelope-open", "envelope-open"),
    ("envelope", "envelope"),
    ("earth-africa", "earth-africa"),
    ("earth-europe", "earth-europe"),
    ("globe", "globe"),
    ("chevron-down", "chevron-down"),
    ("chevron-left", "chevron-left"),
    ("chevron-right", "chevron-right"),
    ("chevron-up", "chevron-up"),
    ("plus-circle", "plus-circle"),
    ("wallet", "wallet"),
    ("lock-alt-solid", "lock-alt-solid"),
    ("lock-alt", "lock-alt"),
    ("heart", "heart"),
    ("bars", "bars"),
    ("plus", "plus"),
    ("minus", "minus"),
    ("times", "times"),
    ("truck-solid", "truck-solid"),
    ("truck", "truck"),
    ("check", "check"),
    ("receipt-solid", "receipt-solid"),
    ("receipt", "receipt"),
    ("exclamation", "exclamation"),
    ("play", "play"),
    ("star", "star"),
    ("star-half", "star-half"),
    ("arrow-right", "arrow-right"),
    ("arrow-up", "arrow-up"),
    ("arrow-down", "arrow-down"),
    ("arrow-left", "arrow-left"),
    ("heart-solid", "heart-solid"),
    ("info", "info"),
    ("exclamation-triangle", "exclamation-triangle"),
    ("tag", "tag"),
    ("angle-double-down", "angle-double-down"),
    ("angle-double-right", "angle-double-right"),
    ("angle-double-left", "angle-double-left"),
    ("angle-double-up", "angle-double-up"),
    ("angle-right", "angle-right"),
    ("angle-left", "angle-left"),
    ("angle-up", "angle-up"),
    ("angle-down", "angle-down"),
    ("chevron-double-right", "chevron-double-right"),
    ("chevron-double-left", "chevron-double-left"),
    ("chevron-double-down", "chevron-double-down"),
    ("chevron-double-up", "chevron-double-up"),
    ("users", "users"),
    ("badge-check", "badge-check"),
    ("arrow-circle-right", "arrow-circle-right"),
    ("arrow-circle-down", "arrow-circle-down"),
    ("check-circle", "check-circle"),
    ("arrow-circle-left", "arrow-circle-left"),
    ("arrow-circle-up", "arrow-circle-up"),
    ("th", "th"),
    ("ruler", "ruler"),
    ("question", "question"),
    ("headphones", "headphones"),
    ("shopping-bag", "shopping-bag"),
    ("minus-circle", "minus-circle"),
    ("leaf", "leaf"),
    ("star-half-solid", "star-half-solid"),
    ("star-solid", "star-solid"),
    ("user-solid", "user-solid"),
    ("lock-solid", "lock-solid"),
    ("bell-solid", "bell-solid"),
    ("thumbs-up-solid", "thumbs-up-solid"),
    ("thumbs-down-solid", "thumbs-down-solid"),
    ("cog-solid", "cog-solid"),
    ("paper-plane", "paper-plane"),
    ("address-book", "address-book"),
    ("inbox", "inbox"),
    ("tags", "tags"),
    ("map-marker-alt", "map-marker-alt"),
    ("box-open", "box-open"),
    ("cog", "cog"),
    ("fire", "fire"),
    ("sync", "sync"),
    ("sync-alt", "sync-alt"),
    ("long-arrow-right", "long-arrow-right"),
    ("search", "search"),
    ("location", "location"),
    ("megaphone", "megaphone"),
    ("thumbs-up", "thumbs-up"),
    ("thumbs-down", "thumbs-down"),
    ("list", "list"),
    ("pencil", "pencil"),
    ("eye-slash", "eye-slash"),
    ("eye", "eye"),
    ("check-fas", "check-fas"),
    ("sign-out", "sign-out"),
    ("user", "user"),
    ("bell", "bell"),
    ("download", "download"),
    ("clock", "clock"),
    ("trash-alt", "trash-alt"),
    ("clipboard-list", "clipboard-list"),
    ("layer-group", "layer-group"),
    ("layer-plus", "layer-plus"),
    ("info-circle", "info-circle"),
    ("info-square", "info-square"),
    ("times-circle", "times-circle"),
    ("tags-solid", "tags-solid"),
    ("address-book-solid", "address-book-solid"),
    ("paper-plane-solid", "paper-plane-solid"),
    ("inbox-solid", "inbox-solid"),
    ("archive-solid", "archive-solid"),
    ("long-arrow-left", "long-arrow-left"),
    ("exchange", "exchange"),
    ("directions-solid", "directions-solid"),
    ("directions", "directions"),
    ("calendar-range", "calendar-range"),
    ("calendar-alt", "calendar-alt"),
    ("sliders", "sliders"),
    ("user-secret", "user-secret"),
    ("pause", "pause"),
    ("rocket-launch", "rocket-launch"),
    ("mug-hot", "mug-hot"),
    ("calendar-days", "calendar-days"),
    ("share-from", "share-from"),
    ("bag-shopping", "bag-shopping"),
    ("copy-regular", "copy-regular"),
    ("glass", "glass"),
    ("folder-open", "folder-open"),
    ("frown-o", "frown-o"),
    ("clipboard", "clipboard"),
    ("xmark", "xmark"),
    ("magnifying-glass-minus", "magnifying-glass-minus"),
    ("magnifying-glass-plus", "magnifying-glass-plus"),
    ("caret-up", "caret-up"),
    ("caret-right", "caret-right"),
    ("caret-left", "caret-left"),
    ("caret-down", "caret-down"),
    ("pinterest", "pinterest"),
    ("facebook", "facebook"),
    ("whatsapp", "whatsapp"),
    ("instagram", "instagram"),
    ("youtube", "youtube"),
    ("google-plus", "google-plus"),
    ("linkedin", "linkedin"),
    ("twitter", "twitter"),
]



from django.utils.translation import gettext as _

from wagtail import blocks

from ocyan.main.loading import get_ocyan_class

from ocyan.plugin.coyote.custom_blocks import ColorChoiceBlock, LinkChooserBlock

COYOTE_COLOR_CHOICES = get_ocyan_class("coyote.variables", "COYOTE_COLOR_CHOICES")


class CoyoteAnchorBlock(blocks.StaticBlock):
    "The anchor block adds a unique anchor id to each block it is added to"

    def value_from_datadict(self, data, files, prefix):
        # the prefix is a unique value
        return prefix

    class Meta:
        admin_text = ""
        label = " "


class CoyoteStructBlock(blocks.StructBlock):
    coyote_anchor = CoyoteAnchorBlock()
    coyote_bg = ColorChoiceBlock()

    class Meta:
        icon = "site"


class CoyoteColorChoiceBlock(blocks.ChoiceBlock):
    choices = COYOTE_COLOR_CHOICES


class CoyoteButtonBlock(blocks.StructBlock):
    label = blocks.CharBlock(required=False, label=_("Label"))
    link = LinkChooserBlock(required=False, label=_("Page URL"))
    new_tab = blocks.BooleanBlock(
        required=False, default=False, label=_("Open in new tab")
    )
    button_style = CoyoteColorChoiceBlock(label=_("Button style"), required=False)

    class Meta:
        preview_template = "preview/bootstrap/button.html"
        label = _("Button")
        group = "Bootstrap"
        icon = "error"


class CoyoteInlineBlock(blocks.StructBlock):
    class Meta:
        # form_template = "coyote/formtemplates/inline.html"
        form_classname = "coyote_inline"



# Generated by Django 3.2.20 on 2023-10-26 07:05

from django.db import migrations, models
import django.db.models.deletion
import wagtail.blocks
import wagtail.fields
import wagtail.embeds.blocks
import wagtail.images.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailimages', '0023_add_choose_permissions'),
        ('coyote', '0003_auto_20230907_1200'),
    ]

    operations = [
        migrations.AddField(
            model_name='coyotecontactpage',
            name='search_image',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.image', verbose_name='Search image'),
        ),
        migrations.AddField(
            model_name='coyotehomepage',
            name='search_image',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.image', verbose_name='Search image'),
        ),
        migrations.AlterField(
            model_name='coyotecontactpage',
            name='content',
            field=wagtail.fields.StreamField([('Info_blokjes', wagtail.blocks.StructBlock([('main_title', wagtail.blocks.CharBlock(lable='Hoofd titel', required=False)), ('main_text', wagtail.blocks.RichTextBlock(label='Hoofd tekst', required=False)), ('blok', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('title', wagtail.blocks.CharBlock(label='Blokje titel', required=True)), ('text', wagtail.blocks.RichTextBlock(label='Blokje tekst', required=True)), ('link', wagtail.blocks.CharBlock(label='Lees meer', required=True))]), collapsed=True, required=True))], icon='list-ol')), ('accordion', wagtail.blocks.StructBlock([('image', wagtail.images.blocks.ImageChooserBlock(label='foto', required=True)), ('title', wagtail.blocks.CharBlock(label='Titel van de tekst', required=False)), ('text', wagtail.blocks.RichTextBlock(label='Tekst', required=False)), ('accordion', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('title_accordion', wagtail.blocks.CharBlock(label='Accordion titel ', required=False)), ('text_accordion', wagtail.blocks.RichTextBlock(label='Accordion text ', required=False))]), collapsed=True, required=True))], icon='info-circle')), ('Center_tekts', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='collapse-down')), ('Logos', wagtail.blocks.StructBlock([('header', wagtail.blocks.CharBlock(label='Header', required=False)), ('logos', wagtail.blocks.ListBlock(wagtail.images.blocks.ImageChooserBlock(), collapsed=True, required=False))], icon='tag')), ('Quotes', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='openquote')), ('Jumbotron', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='form')), ('Accordeon', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='list-ul')), ('Producten', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='tag')), ('Categorieen', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='clipboard-list'))], blank=True, verbose_name='Inhoud'),
        ),
        migrations.AlterField(
            model_name='coyotecontactpage',
            name='footer',
            field=wagtail.fields.StreamField([('Call_To_Action', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='chain-broken')), ('Nieuwsbrief', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='mail'))], blank=True, verbose_name='Footer'),
        ),
        migrations.AlterField(
            model_name='coyotecontactpage',
            name='header',
            field=wagtail.fields.StreamField([('Foto', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('title', wagtail.blocks.CharBlock(label='titel', required=True)), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))]))], blank=True, verbose_name='Header'),
        ),
        migrations.AlterField(
            model_name='coyotehomepage',
            name='content',
            field=wagtail.fields.StreamField([('Afbeelding_met_tekst', wagtail.blocks.StructBlock([('layout', wagtail.blocks.ChoiceBlock(choices=[('layout1', 'coyote/layouts/layout_image_text_2.png'), ('layout2', 'coyote/layouts/layout_image_text_1.png')])), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('title', wagtail.blocks.CharBlock(label='titel', required=True)), ('body', wagtail.blocks.TextBlock(required=False)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('counter', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('number', wagtail.blocks.CharBlock(required=False)), ('label', wagtail.blocks.CharBlock(required=False))]), collapsed=True, label='Counter', required=False))], icon='image')), ('Iconen_met_tekst', wagtail.blocks.StructBlock([('layout', wagtail.blocks.ChoiceBlock(choices=[('layout1', 'coyote/layouts/icon_layout_1.png'), ('layout2', 'coyote/layouts/icon_layout_2.png')])), ('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('icons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('icon', wagtail.blocks.ChoiceBlock(choices=[('share-nodes-solid', 'share-nodes-solid'), ('share-nodes', 'share-nodes'), ('share', 'share'), ('share-from-square', 'share-from-square'), ('spider-web', 'spider-web'), ('folder', 'folder'), ('folder-solid', 'folder-solid'), ('list-check', 'list-check'), ('cloud-arrow-down', 'cloud-arrow-down'), ('cloud-arrow-down-solid', 'cloud-arrow-down-solid'), ('download-solid', 'download-solid'), ('upload', 'upload'), ('upload-solid', 'upload-solid'), ('cloud-arrow-up-solid', 'cloud-arrow-up-solid'), ('cloud-arrow-up', 'cloud-arrow-up'), ('home', 'home'), ('phone', 'phone'), ('comment', 'comment'), ('cart-arrow-down', 'cart-arrow-down'), ('cart-shopping-fast', 'cart-shopping-fast'), ('shopping-cart', 'shopping-cart'), ('shopping-cart-solid', 'shopping-cart-solid'), ('trash', 'trash'), ('arrow-down-arrow-up', 'arrow-down-arrow-up'), ('sort-numeric-down-alt', 'sort-numeric-down-alt'), ('sort-alpha-down', 'sort-alpha-down'), ('circle', 'circle'), ('filter', 'filter'), ('cloud', 'cloud'), ('letter', 'letter'), ('letter-open', 'letter-open'), ('envelope-open', 'envelope-open'), ('envelope', 'envelope'), ('earth-africa', 'earth-africa'), ('earth-europe', 'earth-europe'), ('globe', 'globe'), ('chevron-down', 'chevron-down'), ('chevron-left', 'chevron-left'), ('chevron-right', 'chevron-right'), ('chevron-up', 'chevron-up'), ('plus-circle', 'plus-circle'), ('wallet', 'wallet'), ('lock-alt-solid', 'lock-alt-solid'), ('lock-alt', 'lock-alt'), ('heart', 'heart'), ('bars', 'bars'), ('plus', 'plus'), ('minus', 'minus'), ('times', 'times'), ('truck-solid', 'truck-solid'), ('truck', 'truck'), ('check', 'check'), ('receipt-solid', 'receipt-solid'), ('receipt', 'receipt'), ('exclamation', 'exclamation'), ('play', 'play'), ('star', 'star'), ('star-half', 'star-half'), ('arrow-right', 'arrow-right'), ('arrow-up', 'arrow-up'), ('arrow-down', 'arrow-down'), ('arrow-left', 'arrow-left'), ('heart-solid', 'heart-solid'), ('info', 'info'), ('exclamation-triangle', 'exclamation-triangle'), ('tag', 'tag'), ('angle-double-down', 'angle-double-down'), ('angle-double-right', 'angle-double-right'), ('angle-double-left', 'angle-double-left'), ('angle-double-up', 'angle-double-up'), ('angle-right', 'angle-right'), ('angle-left', 'angle-left'), ('angle-up', 'angle-up'), ('angle-down', 'angle-down'), ('chevron-double-right', 'chevron-double-right'), ('chevron-double-left', 'chevron-double-left'), ('chevron-double-down', 'chevron-double-down'), ('chevron-double-up', 'chevron-double-up'), ('users', 'users'), ('badge-check', 'badge-check'), ('arrow-circle-right', 'arrow-circle-right'), ('arrow-circle-down', 'arrow-circle-down'), ('check-circle', 'check-circle'), ('arrow-circle-left', 'arrow-circle-left'), ('arrow-circle-up', 'arrow-circle-up'), ('th', 'th'), ('ruler', 'ruler'), ('question', 'question'), ('headphones', 'headphones'), ('shopping-bag', 'shopping-bag'), ('minus-circle', 'minus-circle'), ('leaf', 'leaf'), ('star-half-solid', 'star-half-solid'), ('star-solid', 'star-solid'), ('user-solid', 'user-solid'), ('lock-solid', 'lock-solid'), ('bell-solid', 'bell-solid'), ('thumbs-up-solid', 'thumbs-up-solid'), ('thumbs-down-solid', 'thumbs-down-solid'), ('cog-solid', 'cog-solid'), ('paper-plane', 'paper-plane'), ('address-book', 'address-book'), ('inbox', 'inbox'), ('tags', 'tags'), ('map-marker-alt', 'map-marker-alt'), ('box-open', 'box-open'), ('cog', 'cog'), ('fire', 'fire'), ('sync', 'sync'), ('sync-alt', 'sync-alt'), ('long-arrow-right', 'long-arrow-right'), ('search', 'search'), ('location', 'location'), ('megaphone', 'megaphone'), ('thumbs-up', 'thumbs-up'), ('thumbs-down', 'thumbs-down'), ('list', 'list'), ('pencil', 'pencil'), ('eye-slash', 'eye-slash'), ('eye', 'eye'), ('check-fas', 'check-fas'), ('sign-out', 'sign-out'), ('user', 'user'), ('bell', 'bell'), ('download', 'download'), ('clock', 'clock'), ('trash-alt', 'trash-alt'), ('clipboard-list', 'clipboard-list'), ('layer-group', 'layer-group'), ('layer-plus', 'layer-plus'), ('info-circle', 'info-circle'), ('info-square', 'info-square'), ('times-circle', 'times-circle'), ('tags-solid', 'tags-solid'), ('address-book-solid', 'address-book-solid'), ('paper-plane-solid', 'paper-plane-solid'), ('inbox-solid', 'inbox-solid'), ('archive-solid', 'archive-solid'), ('long-arrow-left', 'long-arrow-left'), ('exchange', 'exchange'), ('directions-solid', 'directions-solid'), ('directions', 'directions'), ('calendar-range', 'calendar-range'), ('calendar-alt', 'calendar-alt'), ('sliders', 'sliders'), ('user-secret', 'user-secret'), ('pause', 'pause'), ('rocket-launch', 'rocket-launch'), ('mug-hot', 'mug-hot'), ('calendar-days', 'calendar-days'), ('share-from', 'share-from'), ('bag-shopping', 'bag-shopping'), ('copy-regular', 'copy-regular'), ('glass', 'glass'), ('folder-open', 'folder-open'), ('frown-o', 'frown-o'), ('clipboard', 'clipboard'), ('xmark', 'xmark'), ('magnifying-glass-minus', 'magnifying-glass-minus'), ('magnifying-glass-plus', 'magnifying-glass-plus'), ('caret-up', 'caret-up'), ('caret-right', 'caret-right'), ('caret-left', 'caret-left'), ('caret-down', 'caret-down'), ('pinterest', 'pinterest'), ('facebook', 'facebook'), ('whatsapp', 'whatsapp'), ('instagram', 'instagram'), ('youtube', 'youtube'), ('google-plus', 'google-plus'), ('linkedin', 'linkedin'), ('twitter', 'twitter')], required=False)), ('header', wagtail.blocks.CharBlock(label='Header', required=False)), ('body', wagtail.blocks.TextBlock(label='Short text', max_length=100, required=False)), ('page', wagtail.blocks.PageChooserBlock(label='Pagina url', required=False))]), collapsed=True, label='Text Block', required=False)), ('button', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))], required=False))], icon='info-circle')), ('Center_tekts', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(required=False))], icon='collapse-down')), ('Logos', wagtail.blocks.StructBlock([('header', wagtail.blocks.CharBlock(label='Header', required=False)), ('logos', wagtail.blocks.ListBlock(wagtail.images.blocks.ImageChooserBlock(), collapsed=True, required=False))], icon='tag')), ('Quotes', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='openquote')), ('Jumbotron', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='form')), ('Accordeon', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='list-ul')), ('Tabs', wagtail.blocks.StructBlock([('header', wagtail.blocks.CharBlock(label='Header', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('tabs', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('header', wagtail.blocks.CharBlock(label='Header')), ('body', wagtail.blocks.RichTextBlock(label='Inhoud')), ('button', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))], required=False))]), collapsed=True, label='Tabs', required=False))], icon='list-ul')), ('Producten', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='tag')), ('Categorieen', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='clipboard-list'))], blank=True, verbose_name='Inhoud'),
        ),
        migrations.AlterField(
            model_name='coyotehomepage',
            name='footer',
            field=wagtail.fields.StreamField([('Call_To_Action', wagtail.blocks.StructBlock([('icon', wagtail.blocks.ChoiceBlock(choices=[('share-nodes-solid', 'share-nodes-solid'), ('share-nodes', 'share-nodes'), ('share', 'share'), ('share-from-square', 'share-from-square'), ('spider-web', 'spider-web'), ('folder', 'folder'), ('folder-solid', 'folder-solid'), ('list-check', 'list-check'), ('cloud-arrow-down', 'cloud-arrow-down'), ('cloud-arrow-down-solid', 'cloud-arrow-down-solid'), ('download-solid', 'download-solid'), ('upload', 'upload'), ('upload-solid', 'upload-solid'), ('cloud-arrow-up-solid', 'cloud-arrow-up-solid'), ('cloud-arrow-up', 'cloud-arrow-up'), ('home', 'home'), ('phone', 'phone'), ('comment', 'comment'), ('cart-arrow-down', 'cart-arrow-down'), ('cart-shopping-fast', 'cart-shopping-fast'), ('shopping-cart', 'shopping-cart'), ('shopping-cart-solid', 'shopping-cart-solid'), ('trash', 'trash'), ('arrow-down-arrow-up', 'arrow-down-arrow-up'), ('sort-numeric-down-alt', 'sort-numeric-down-alt'), ('sort-alpha-down', 'sort-alpha-down'), ('circle', 'circle'), ('filter', 'filter'), ('cloud', 'cloud'), ('letter', 'letter'), ('letter-open', 'letter-open'), ('envelope-open', 'envelope-open'), ('envelope', 'envelope'), ('earth-africa', 'earth-africa'), ('earth-europe', 'earth-europe'), ('globe', 'globe'), ('chevron-down', 'chevron-down'), ('chevron-left', 'chevron-left'), ('chevron-right', 'chevron-right'), ('chevron-up', 'chevron-up'), ('plus-circle', 'plus-circle'), ('wallet', 'wallet'), ('lock-alt-solid', 'lock-alt-solid'), ('lock-alt', 'lock-alt'), ('heart', 'heart'), ('bars', 'bars'), ('plus', 'plus'), ('minus', 'minus'), ('times', 'times'), ('truck-solid', 'truck-solid'), ('truck', 'truck'), ('check', 'check'), ('receipt-solid', 'receipt-solid'), ('receipt', 'receipt'), ('exclamation', 'exclamation'), ('play', 'play'), ('star', 'star'), ('star-half', 'star-half'), ('arrow-right', 'arrow-right'), ('arrow-up', 'arrow-up'), ('arrow-down', 'arrow-down'), ('arrow-left', 'arrow-left'), ('heart-solid', 'heart-solid'), ('info', 'info'), ('exclamation-triangle', 'exclamation-triangle'), ('tag', 'tag'), ('angle-double-down', 'angle-double-down'), ('angle-double-right', 'angle-double-right'), ('angle-double-left', 'angle-double-left'), ('angle-double-up', 'angle-double-up'), ('angle-right', 'angle-right'), ('angle-left', 'angle-left'), ('angle-up', 'angle-up'), ('angle-down', 'angle-down'), ('chevron-double-right', 'chevron-double-right'), ('chevron-double-left', 'chevron-double-left'), ('chevron-double-down', 'chevron-double-down'), ('chevron-double-up', 'chevron-double-up'), ('users', 'users'), ('badge-check', 'badge-check'), ('arrow-circle-right', 'arrow-circle-right'), ('arrow-circle-down', 'arrow-circle-down'), ('check-circle', 'check-circle'), ('arrow-circle-left', 'arrow-circle-left'), ('arrow-circle-up', 'arrow-circle-up'), ('th', 'th'), ('ruler', 'ruler'), ('question', 'question'), ('headphones', 'headphones'), ('shopping-bag', 'shopping-bag'), ('minus-circle', 'minus-circle'), ('leaf', 'leaf'), ('star-half-solid', 'star-half-solid'), ('star-solid', 'star-solid'), ('user-solid', 'user-solid'), ('lock-solid', 'lock-solid'), ('bell-solid', 'bell-solid'), ('thumbs-up-solid', 'thumbs-up-solid'), ('thumbs-down-solid', 'thumbs-down-solid'), ('cog-solid', 'cog-solid'), ('paper-plane', 'paper-plane'), ('address-book', 'address-book'), ('inbox', 'inbox'), ('tags', 'tags'), ('map-marker-alt', 'map-marker-alt'), ('box-open', 'box-open'), ('cog', 'cog'), ('fire', 'fire'), ('sync', 'sync'), ('sync-alt', 'sync-alt'), ('long-arrow-right', 'long-arrow-right'), ('search', 'search'), ('location', 'location'), ('megaphone', 'megaphone'), ('thumbs-up', 'thumbs-up'), ('thumbs-down', 'thumbs-down'), ('list', 'list'), ('pencil', 'pencil'), ('eye-slash', 'eye-slash'), ('eye', 'eye'), ('check-fas', 'check-fas'), ('sign-out', 'sign-out'), ('user', 'user'), ('bell', 'bell'), ('download', 'download'), ('clock', 'clock'), ('trash-alt', 'trash-alt'), ('clipboard-list', 'clipboard-list'), ('layer-group', 'layer-group'), ('layer-plus', 'layer-plus'), ('info-circle', 'info-circle'), ('info-square', 'info-square'), ('times-circle', 'times-circle'), ('tags-solid', 'tags-solid'), ('address-book-solid', 'address-book-solid'), ('paper-plane-solid', 'paper-plane-solid'), ('inbox-solid', 'inbox-solid'), ('archive-solid', 'archive-solid'), ('long-arrow-left', 'long-arrow-left'), ('exchange', 'exchange'), ('directions-solid', 'directions-solid'), ('directions', 'directions'), ('calendar-range', 'calendar-range'), ('calendar-alt', 'calendar-alt'), ('sliders', 'sliders'), ('user-secret', 'user-secret'), ('pause', 'pause'), ('rocket-launch', 'rocket-launch'), ('mug-hot', 'mug-hot'), ('calendar-days', 'calendar-days'), ('share-from', 'share-from'), ('bag-shopping', 'bag-shopping'), ('copy-regular', 'copy-regular'), ('glass', 'glass'), ('folder-open', 'folder-open'), ('frown-o', 'frown-o'), ('clipboard', 'clipboard'), ('xmark', 'xmark'), ('magnifying-glass-minus', 'magnifying-glass-minus'), ('magnifying-glass-plus', 'magnifying-glass-plus'), ('caret-up', 'caret-up'), ('caret-right', 'caret-right'), ('caret-left', 'caret-left'), ('caret-down', 'caret-down'), ('pinterest', 'pinterest'), ('facebook', 'facebook'), ('whatsapp', 'whatsapp'), ('instagram', 'instagram'), ('youtube', 'youtube'), ('google-plus', 'google-plus'), ('linkedin', 'linkedin'), ('twitter', 'twitter')], required=False)), ('header', wagtail.blocks.CharBlock(required=False)), ('body', wagtail.blocks.TextBlock(required=False)), ('button', wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))], required=False))], icon='chain-broken')), ('Nieuwsbrief', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))], icon='mail'))], blank=True, verbose_name='Footer'),
        ),
        migrations.AlterField(
            model_name='coyotehomepage',
            name='header',
            field=wagtail.fields.StreamField([('Foto', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False)), ('center_text', wagtail.blocks.BooleanBlock(label='Center the body', required=False))])), ('Video', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('video', wagtail.embeds.blocks.EmbedBlock(label='Video', required=False)), ('overlay', wagtail.blocks.BooleanBlock(label='Dark overlay', required=False))])), ('Content', wagtail.blocks.StructBlock([('body', wagtail.blocks.RichTextBlock(label='Inhoud', required=True)), ('buttons', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(required=False)), ('page_url', wagtail.blocks.PageChooserBlock(required=False)), ('external_url', wagtail.blocks.CharBlock(help_text='You can also use the mailto: or tel: preset for functional use', label='External url', required=False)), ('new_tab', wagtail.blocks.BooleanBlock(default=False, label='Open in new tab', required=False)), ('button_style', wagtail.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('light', 'Light'), ('dark', 'Dark'), ('info', 'Info'), ('success', 'Success'), ('warning', 'Warning'), ('danger', 'Danger')], label='Button style', required=False))]), collapsed=True, label='Buttons', required=False)), ('image', wagtail.images.blocks.ImageChooserBlock(label='Afbeelding')), ('position', wagtail.blocks.ChoiceBlock(choices=[('left', 'Links'), ('right', 'Rechts')], label='Postion of the image', required=False))]))], blank=True, verbose_name='Header'),
        ),
    ]



# Generated by Django 3.2.23 on 2023-11-24 11:12

from django.db import migrations, models
import wagtail.blocks
import wagtail.fields
import wagtail.embeds.blocks
import wagtail.images.blocks

from oxyan.themes.definitions import theme


class Migration(migrations.Migration):

    dependencies = [
        ('coyote', '0009_auto_20231117_0945'),
    ]

    operations = [
        migrations.AddField(
            model_name='colorsetting',
            name='footer_background',
            field=models.CharField(default=theme["header-background"], max_length=7, verbose_name='Background footer'),
        ),
        migrations.AddField(
            model_name='colorsetting',
            name='header_background',
            field=models.CharField(default=theme["header-background"], max_length=7, verbose_name='Background header'),
        ),
        migrations.AlterField(
            model_name='colorsetting',
            name='gray_200',
            field=models.CharField(default=theme["gray-200"], max_length=7, verbose_name='Light'),
        ),
        migrations.AlterField(
            model_name='colorsetting',
            name='gray_900',
            field=models.CharField(default=theme["gray-900"], max_length=7, verbose_name='Dark'),
        ),
        migrations.AlterField(
            model_name='colorsetting',
            name='primary',
            field=models.CharField(default=theme["primary"], max_length=7),
        ),
        migrations.AlterField(
            model_name='colorsetting',
            name='secondary',
            field=models.CharField(default=theme["secondary"], max_length=7),
        ),
        migrations.AlterField(
            model_name='coyotecontactpage',
            name='content',
            field=wagtail.fields.StreamField([], blank=True, verbose_name='Inhoud'),
        ),
        migrations.AlterField(
            model_name='coyotehomepage',
            name='content',
            field=wagtail.fields.StreamField([], blank=True, verbose_name='Inhoud'),
        ),
        migrations.AlterField(
            model_name='coyotehomepage',
            name='header',
            field=wagtail.fields.StreamField([], blank=True, verbose_name='Header'),
        ),
    ]



from importlib import import_module
from pathlib import Path

from django.forms import modelform_factory
from django.template import Context, Template
from django.template.loader import get_template
from django.test import SimpleTestCase

from ocyan.plugin.coyote.blocks.content import CoyoteTabsBlock
from ocyan.plugin.coyote.forms import StyleSettingsForm
from ocyan.plugin.coyote.models import (
    CoyoteContactPage,
    CoyoteHomePage,
    StyleSettings,
)


class CoyoteSmokeTests(SimpleTestCase):
    LEGACY_THEME_IMPORT_MIGRATIONS = {
        "0010_auto_20231127_1018.py",
        "0014_remove_stylesettings_site_and_more.py",
        "0017_stylesettings_body_color_stylesettings_border_radius.py",
        "0018_alter_stylesettings_border_radius.py",
        "0019_auto_20250512_1642.py",
        "0020_stylesettings_header.py",
        "0021_fix_incorrect_header_default_setting.py",
    }

    def test_app_import(self):
        module = import_module("ocyan.plugin.coyote")
        self.assertTrue(hasattr(module, "CoyoteConfig"))

    def test_app_config_import(self):
        module = import_module("ocyan.plugin.coyote.apps")
        self.assertEqual(
            module.OcyanPluginCoyoteAppConfig.name,
            "ocyan.plugin.coyote",
        )

    def test_models_import(self):
        self.assertEqual(CoyoteHomePage.__name__, "CoyoteHomePage")
        self.assertEqual(CoyoteContactPage.__name__, "CoyoteContactPage")
        self.assertEqual(StyleSettings.__name__, "StyleSettings")

    def test_block_import(self):
        self.assertEqual(CoyoteTabsBlock.__name__, "CoyoteTabsBlock")

    def test_settings_form_import(self):
        self.assertEqual(StyleSettingsForm.__name__, "StyleSettingsForm")

    def test_style_settings_form_labels_are_client_neutral(self):
        form_class = modelform_factory(
            StyleSettings, form=StyleSettingsForm, fields="__all__"
        )
        form = form_class()

        self.assertEqual(str(form.fields["primary"].label), "Primary color")
        self.assertEqual(str(form.fields["secondary"].label), "Secondary color")
        self.assertEqual(str(form.fields["gray_900"].label), "Dark accent color")
        self.assertEqual(str(form.fields["gray_200"].label), "Light accent color")
        self.assertEqual(str(form.fields["body_color"].label), "Body text color")
        self.assertEqual(
            str(form.fields["body_background"].label), "Body background color"
        )
        self.assertEqual(
            str(form.fields["footer_background"].label), "Footer background color"
        )
        self.assertEqual(
            str(form.fields["header_background"].label), "Header background color"
        )
        self.assertEqual(
            str(form.fields["header_font_family"].help_text),
            "Used for headings across the Coyote theme.",
        )
        self.assertEqual(
            str(form.fields["paragraph_font_family"].help_text),
            "Used for paragraph text across the Coyote theme.",
        )
        self.assertEqual(str(form.fields["border_radius"].label), "Border radius")

    def test_style_settings_source_uses_translatable_english_panel_headings(self):
        models_source = (
            Path(__file__).resolve().parent.parent / "models.py"
        ).read_text(encoding="utf-8")
        self.assertIn('heading=_("Colors")', models_source)
        self.assertIn('heading=_("Typography")', models_source)
        self.assertIn('heading=_("General")', models_source)
        self.assertNotIn('heading="Kleuren"', models_source)
        self.assertNotIn('heading="Typografie"', models_source)
        self.assertNotIn('heading="Overig"', models_source)

    def test_live_editor_labels_use_normalized_english_copy(self):
        models_source = (
            Path(__file__).resolve().parent.parent / "models.py"
        ).read_text(encoding="utf-8")
        stream_blocks_source = (
            Path(__file__).resolve().parent.parent / "stream_blocks.py"
        ).read_text(encoding="utf-8")
        content_blocks_source = (
            Path(__file__).resolve().parent.parent / "blocks/content.py"
        ).read_text(encoding="utf-8")
        partial_blocks_source = (
            Path(__file__).resolve().parent.parent / "blocks/partials.py"
        ).read_text(encoding="utf-8")

        self.assertIn('verbose_name=_("Content")', models_source)
        self.assertNotIn('verbose_name="Inhoud"', models_source)
        self.assertIn('_("Paragraph columns")', stream_blocks_source)
        self.assertNotIn('_("Paragraph colums")', stream_blocks_source)
        self.assertIn('_("Logos")', stream_blocks_source)
        self.assertIn('_("Logos")', content_blocks_source)
        self.assertNotIn('_("Logo\\\'s")', stream_blocks_source)
        self.assertNotIn('_("Logo\\\'s")', content_blocks_source)
        self.assertIn('_("LinkedIn")', content_blocks_source)
        self.assertNotIn('_("Linkedin")', content_blocks_source)
        self.assertIn('_("Page URL")', partial_blocks_source)
        self.assertNotIn('_("Page url")', partial_blocks_source)

    def test_public_template_fallback_copy_is_translatable(self):
        category_template = (
            Path(__file__).resolve().parent.parent
            / "templates/coyote/blocks/content/categoryblock.html"
        ).read_text(encoding="utf-8")
        tabs_template = (
            Path(__file__).resolve().parent.parent
            / "templates/coyote/blocks/content/tabsblock.html"
        ).read_text(encoding="utf-8")

        self.assertIn('{% trans "Products" %}', category_template)
        self.assertNotIn("Producten", category_template)
        self.assertIn("{% load wagtailcore_tags ocyan_thumbnail i18n %}", tabs_template)
        self.assertIn("default:_('Tabbed content')", tabs_template)
        self.assertIn("default:_('Tabbed content image')", tabs_template)
        self.assertNotIn("default:'Tabbed content'", tabs_template)
        self.assertNotIn("default:'Tabbed content image'", tabs_template)

    def test_theme_extension_imports(self):
        module = import_module("ocyan.plugin.coyote.theme_extension")
        self.assertIsNotNone(module)

    def test_template_pages_load(self):
        self.assertIsNotNone(get_template("coyote/pages/home.html"))
        self.assertIsNotNone(get_template("coyote/pages/contact.html"))
        self.assertIsNotNone(get_template("coyote/coyote_page.html"))

    def test_theme_extension_template_loads(self):
        self.assertIsNotNone(get_template("base.html"))

    def test_compiled_public_css_assets_exist(self):
        static_dir = Path(__file__).resolve().parent.parent / "static/coyote/css"
        self.assertTrue((static_dir / "base.css").exists())
        self.assertTrue((static_dir / "homepage/base.css").exists())
        self.assertTrue((static_dir / "contact/base.css").exists())

    def test_public_style_partials_reference_compiled_css_by_default(self):
        template_root = (
            Path(__file__).resolve().parent.parent / "templates/coyote/partials/styles"
        )
        base_template = (template_root / "base_styles.html").read_text(encoding="utf-8")
        home_template = (template_root / "home_styles.html").read_text(encoding="utf-8")
        contact_template = (template_root / "contact_styles.html").read_text(
            encoding="utf-8"
        )

        self.assertIn("coyote/css/base.css", base_template)
        self.assertIn("coyote/css/homepage/base.css", home_template)
        self.assertIn("coyote/css/contact/base.css", contact_template)
        self.assertNotIn('type="text/x-scss"', base_template)
        self.assertNotIn('type="text/x-scss"', home_template)
        self.assertNotIn('type="text/x-scss"', contact_template)

    def test_readme_documents_scss_source_and_host_override_contract(self):
        readme = (Path(__file__).resolve().parents[4] / "README.md").read_text(
            encoding="utf-8"
        )
        self.assertIn("SCSS remains the source of truth", readme)
        self.assertIn("static/coyote/base.scss", readme)
        self.assertIn("static/coyote/homepage/base.scss", readme)
        self.assertIn("static/coyote/contact/base.scss", readme)
        self.assertIn("Host override / rebuild contract", readme)
        self.assertIn("django-libsass", readme)
        self.assertIn("static/coyote/css/base.css", readme)

    def test_admin_widget_modules_import(self):
        self.assertIsNotNone(import_module("ocyan.plugin.coyote.custom_blocks.widgets"))
        self.assertIsNotNone(
            import_module("ocyan.plugin.coyote.custom_blocks.adapters")
        )
        self.assertIsNotNone(import_module("ocyan.plugin.coyote.custom_blocks"))

    def test_font_select_widget_template_uses_translatable_copy(self):
        template_path = (
            Path(__file__).resolve().parent.parent
            / "templates/coyote/forms/widgets/fontselect.html"
        )
        content = template_path.read_text(encoding="utf-8")
        self.assertIn('{% trans "Choose a font..." %}', content)
        self.assertNotIn("Kies een font", content)

    def test_coyote_uses_modern_wagtail_admin_telepath_imports(self):
        adapters_source = (
            Path(__file__).resolve().parent.parent / "custom_blocks/adapters.py"
        ).read_text(encoding="utf-8")
        blocks_source = (
            Path(__file__).resolve().parent.parent / "custom_blocks/__init__.py"
        ).read_text(encoding="utf-8")

        self.assertIn(
            "from wagtail.admin.telepath.widgets import WidgetAdapter",
            adapters_source,
        )
        self.assertNotIn(
            "from wagtail.widget_adapters import WidgetAdapter", adapters_source
        )
        self.assertIn("from wagtail.admin.telepath import register", blocks_source)
        self.assertNotIn("from wagtail.telepath import register", blocks_source)

    def test_readme_documents_migration_caveats_and_legacy_theme_default_risk(self):
        readme = (Path(__file__).resolve().parents[4] / "README.md").read_text(
            encoding="utf-8"
        )
        self.assertIn("0024_remove_coyotecontactpage_page_ptr_and_more", readme)
        self.assertIn("0025_remove_coyotecontactpage_page_ptr_and_more", readme)
        self.assertIn("must not be copied into any future", readme)
        self.assertIn("migration pattern", readme)
        self.assertIn("Migration policy", readme)
        self.assertIn("freeze the future without rewriting", readme)

    def test_only_known_historical_migrations_import_live_theme_defaults(self):
        migration_dir = Path(__file__).resolve().parent.parent / "migrations"
        files_with_live_theme_imports = sorted(
            path.name
            for path in migration_dir.glob("*.py")
            if "from oxyan.themes.definitions import theme"
            in path.read_text(encoding="utf-8")
        )

        self.assertEqual(
            files_with_live_theme_imports,
            sorted(self.LEGACY_THEME_IMPORT_MIGRATIONS),
        )

    def test_readme_documents_public_asset_ownership_boundary(self):
        readme = (Path(__file__).resolve().parents[4] / "README.md").read_text(
            encoding="utf-8"
        )
        self.assertIn("Public asset ownership", readme)
        self.assertIn("ships verified compiled fallback/default assets", readme)
        self.assertIn("webpack.config.js", readme)
        self.assertIn("templates/coyote/partials/styles/base_styles.html", readme)

    def test_tabs_template_uses_unique_aria_linkage(self):
        template_path = (
            Path(__file__).resolve().parent.parent
            / "templates/coyote/blocks/content/tabsblock.html"
        )
        content = template_path.read_text(encoding="utf-8")
        self.assertIn('id="{{ tab_id }}"', content)
        self.assertIn('aria-controls="{{ panel_id }}"', content)
        self.assertIn('aria-labelledby="{{ tab_id }}"', content)
        self.assertNotIn('id="pills-home-tab"', content)

    def test_accordion_template_uses_button_control(self):
        template_path = (
            Path(__file__).resolve().parent.parent
            / "templates/coyote/blocks/content/accordion.html"
        )
        content = template_path.read_text(encoding="utf-8")
        self.assertIn("<button", content)
        self.assertIn('class="accordion-button collapsed p-3"', content)
        self.assertIn('aria-controls="{{ collapse_id }}"', content)
        self.assertNotIn('class="accordion-header d-flex collapsed p-3"', content)

    def test_image_alt_and_link_fallback_fixes_present(self):
        category_template = (
            Path(__file__).resolve().parent.parent
            / "templates/coyote/blocks/content/categoryblock.html"
        ).read_text(encoding="utf-8")
        product_template = (
            Path(__file__).resolve().parent.parent
            / "templates/coyote/partials/product_slider_item.html"
        ).read_text(encoding="utf-8")
        info_template = (
            Path(__file__).resolve().parent.parent
            / "templates/coyote/blocks/content/info_block.html"
        ).read_text(encoding="utf-8")
        self.assertIn("alt=cat.category.name", category_template)
        self.assertIn(
            'aria-label="{{ product.title|default:product.get_title }}"',
            product_template,
        )
        self.assertNotIn('href=""', info_template)

    def test_public_page_assets_use_static_files_without_inline_slider_script(self):
        coyote_page = (
            Path(__file__).resolve().parent.parent / "templates/coyote/coyote_page.html"
        ).read_text(encoding="utf-8")
        home_page = (
            Path(__file__).resolve().parent.parent / "templates/coyote/pages/home.html"
        ).read_text(encoding="utf-8")
        contact_page = (
            Path(__file__).resolve().parent.parent
            / "templates/coyote/pages/contact.html"
        ).read_text(encoding="utf-8")
        base_styles_partial = (
            Path(__file__).resolve().parent.parent
            / "templates/coyote/partials/styles/base_styles.html"
        ).read_text(encoding="utf-8")
        home_styles_partial = (
            Path(__file__).resolve().parent.parent
            / "templates/coyote/partials/styles/home_styles.html"
        ).read_text(encoding="utf-8")
        contact_styles_partial = (
            Path(__file__).resolve().parent.parent
            / "templates/coyote/partials/styles/contact_styles.html"
        ).read_text(encoding="utf-8")

        self.assertIn("coyote/js/page_sliders.js", coyote_page)
        self.assertNotIn("oxyan.initSliders", coyote_page)
        self.assertIn(
            '{% include "coyote/partials/styles/base_styles.html" %}', coyote_page
        )
        self.assertIn(
            '{% include "coyote/partials/styles/home_styles.html" %}', home_page
        )
        self.assertIn(
            '{% include "coyote/partials/styles/contact_styles.html" %}',
            contact_page,
        )
        self.assertIn("coyote/css/base.css", base_styles_partial)
        self.assertIn("coyote/css/homepage/base.css", home_styles_partial)
        self.assertIn("coyote/css/contact/base.css", contact_styles_partial)
        self.assertIn(
            "Source SCSS entrypoint: static/coyote/base.scss", base_styles_partial
        )
        self.assertIn(
            "Source SCSS entrypoint: static/coyote/homepage/base.scss",
            home_styles_partial,
        )
        self.assertIn(
            "Source SCSS entrypoint: static/coyote/contact/base.scss",
            contact_styles_partial,
        )

    def test_public_slider_asset_exists(self):
        slider_asset = (
            Path(__file__).resolve().parent.parent / "static/coyote/js/page_sliders.js"
        )
        self.assertTrue(slider_asset.exists())

    def test_public_style_partials_load(self):
        self.assertIsNotNone(get_template("coyote/partials/styles/base_styles.html"))
        self.assertIsNotNone(get_template("coyote/partials/styles/home_styles.html"))
        self.assertIsNotNone(get_template("coyote/partials/styles/contact_styles.html"))

    def test_optional_url_tag_returns_empty_when_missing(self):
        from ocyan.plugin.coyote.templatetags.coyote_tags import optional_url

        self.assertEqual(optional_url("missing:view-name"), "")

    def test_render_optional_template_returns_empty_when_missing(self):
        from ocyan.plugin.coyote.templatetags.coyote_tags import (
            render_optional_template,
        )

        template_context = {}
        self.assertEqual(
            render_optional_template(template_context, "missing/template.html"), ""
        )

    def test_render_optional_template_renders_existing_template(self):
        template = Template(
            "{% load coyote_tags %}"
            "{% render_optional_template 'coyote/partials/fonts.html' font_settings=font_settings %}"
        )
        font_settings = type(
            "FontSettings",
            (),
            {
                "header_font_family": "",
                "paragraph_font_family": "",
                "header_font": "",
                "header_font_variant": "",
                "paragraph_font": "",
                "paragraph_font_variant": "",
            },
        )()
        rendered = template.render(Context({"font_settings": font_settings}))
        self.assertEqual(rendered.strip(), "")

    def test_dependency_boundaries_are_template_guarded(self):
        accordion_template = (
            Path(__file__).resolve().parent.parent
            / "templates/coyote/blocks/content/accordion.html"
        ).read_text(encoding="utf-8")
        contact_template = (
            Path(__file__).resolve().parent.parent
            / "templates/coyote/blocks/content/contact.html"
        ).read_text(encoding="utf-8")
        category_template = (
            Path(__file__).resolve().parent.parent
            / "templates/coyote/blocks/content/categoryblock.html"
        ).read_text(encoding="utf-8")
        product_template = (
            Path(__file__).resolve().parent.parent
            / "templates/coyote/partials/product_slider_item.html"
        ).read_text(encoding="utf-8")

        self.assertIn(
            "load ocyan_thumbnail wagtailcore_tags styling_tags coyote_tags",
            accordion_template,
        )
        self.assertNotIn("roadrunner_tags", accordion_template)
        self.assertIn(
            "optional_url 'contact_form:contact-form-handler'", contact_template
        )
        self.assertIn(
            "render_optional_template 'oscar/partials/form_field.html'",
            contact_template,
        )
        self.assertIn(
            'render_optional_template "oscar/catalogue/partials/stock_record.html"',
            category_template,
        )
        self.assertNotIn(
            '{% extends "oscar/catalogue/partials/product.html" %}',
            product_template,
        )

    def test_contact_template_fallback_message_is_present(self):
        contact_template = (
            Path(__file__).resolve().parent.parent
            / "templates/coyote/blocks/content/contact.html"
        ).read_text(encoding="utf-8")
        self.assertIn("The contact form is currently unavailable.", contact_template)



from django import forms

from wagtail.admin.widgets.chooser import AdminPageChooser


class ColorSelect(forms.RadioSelect):
    pass


class VisualSelect(forms.RadioSelect):
    pass


class IconSelect(forms.RadioSelect):
    pass


class AdminLinkChooser(AdminPageChooser):
    def render_html(self, name, value_data, attrs):
        return ""

    def get_value_data(self, value):
        if isinstance(value, str):
            return {
                "id": value,
                "display_title": f"link: {value}",
                "parent_id": None,
                "edit_url": None,
            }

        return super().get_value_data(value)



# Generated by Django 4.2.11 on 2025-05-12 14:42

from django.db import migrations
from oxyan.themes.definitions import theme


def forward(apps, schema_editor):
    StyleSettings = apps.get_model("coyote", "StyleSettings")

    if qs := StyleSettings.objects.filter(border_radius=0.0):
        qs.update(border_radius=theme["border-radius"])


class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0018_alter_stylesettings_border_radius"),
    ]

    operations = [
        migrations.RunPython(forward, migrations.RunPython.noop)
    ]
